@@ -1,12 +1,15 @@
+from msilib.schema import ComboBox
 import os
 from tkinter.messagebox import NO
 
 from .api import APISession
 
-_config = None
+
 
 class Config:
 
+    _config = None
+
     def __init__(self, verify_tls=True) -> None:
         self.access_token = os.getenv("CTFD_TOKEN", default=None)
         self.url = os.getenv("CTFD_URL", default=None)
@@ -14,13 +17,16 @@ class Config:
 
     @staticmethod
     def generate_config(verify_tls:bool):
-        _config = Config(verify_tls=verify_tls)
+        if Config._config == None:
+            Config._config = Config(verify_tls=verify_tls)
+        return Config._config
+
 
     @staticmethod
     def generate_session():
-        if _config == None:
+        if Config._config == None:
             raise Exception("Config was not initialized!")
 
-        s = APISession(prefix_url=_config.url, verify_tls=_config.verify_tls)
-        s.headers.update({"Authorization": f"Token {_config.access_token}"})
+        s = APISession(prefix_url= Config._config.url, verify_tls= Config._config.verify_tls)
+        s.headers.update({"Authorization": f"Token { Config._config.access_token}"})
         return s
